#
# spec file for package skopeo
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# nodebuginfo


%define project        github.com/containers/skopeo

Name:           skopeo
VCS: https://src.suse.de/ALP-pool/skopeo#ac8513b41beda562bbe0f386251721f4b9a54998
Version:        1.14.4
Release:        2.1
Summary:        Container image repository tool
License:        Apache-2.0
Group:          System/Management
URL:            https://%project
Source:         %{name}-%{version}.tar.xz
Source1:        skopeo.rpmlintrc
Requires:       libcontainers-common
Patch0:         0001-Use-securejoin.SecureJoin-when-forming-userns-paths.patch
BuildRequires:  bash
BuildRequires:  device-mapper-devel >= 1.2.68
BuildRequires:  glib2-devel
BuildRequires:  go-go-md2man
BuildRequires:  libbtrfs-devel >= 3.8
BuildRequires:  libcontainers-common
BuildRequires:  libgpgme-devel
BuildRequires:  golang(API) >= 1.21
ExcludeArch:    s390

%description
skopeo is a command line utility for various operations on container images and
image repositories. skopeo is able to inspect a repository on a Docker registry
and fetch images layers. skopeo can copy container images between various
storage mechanisms.

%package bash-completion
Summary:        Bash completion for skopeo
BuildArch:      noarch
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)

%description bash-completion
This package contains the bash completion for skopeo.

%package fish-completion
Summary:        Fish completion for skopeo
BuildArch:      noarch
Requires:       %{name} = %{version}
Requires:       fish
Supplements:    (%{name} and fish)

%description fish-completion
This package contains the fish completion for skopeo.

%package zsh-completion
Summary:        Zsh completion for skopeo
BuildArch:      noarch
Requires:       %{name} = %{version}
Requires:       zsh
Supplements:    (%{name} and zsh)

%description zsh-completion
This package contains the zsh completion for skopeo.

%prep
%autosetup -p1

%build
mkdir -p .gopath/src/github.com/containers
ln -s $PWD .gopath/src/%{project}
export GOPATH=$PWD/.gopath

export BUILDTAGS="exclude_graphdriver_aufs"

# Build.
GO111MODULE=on go build -mod=vendor "-buildmode=pie" -ldflags "-X main.gitCommit=" -gcflags "" -tags "$BUILDTAGS" -o skopeo %{project}/cmd/skopeo
%make_build docs PREFIX=%{_prefix}

%install
%make_install PREFIX=%{_prefix} install-docs install-completions
# Drop unneeded files
rm -rv %{buildroot}/etc/containers

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
%{_mandir}/man1/skopeo*.1*

%files bash-completion
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/%{name}

%files fish-completion
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_completions.d/%{name}.fish

%files zsh-completion
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_%{name}

%changelog
* Tue Oct 29 2024 madhankumar.chellamuthu@suse.com
- Add patch for CVE-2024-9676 (bsc#1231698)
  * 0001-Use-securejoin.SecureJoin-when-forming-userns-paths.patch
* Mon Jun  3 2024 danish.prakash@suse.com
- Update to version 1.14.4:
  * [release-1.14] Bump to Skopeo v1.14.4
  * [release-1.14] CVE-2024-3727 fix (bsc#1224123)
  * Packit: update packit targets
  * [release-1.14] Bump gopkg.in/go-jose to v2.6.3
  * [release-1.14] Bump ocicrypt and go-jose CVE-2024-28180
  * Freeze the fedora-minimal image reference at Fedora 38
  * [release-1.14] Bump to v1.14.3
  * [release-1.14] Bump c/common to v0.57.4
  * [release-1.14] Bump google.golang.org/protobuf to v1.33.0
  * [release-1.14] Bump Skopeo to v1.14.3-dev
* Mon Feb  5 2024 dcermak@suse.com
- Update to version 1.14.2:
  * [release-1.14] Bump Skopeo to v1.14.2
  * [release-1.14] Bump c/image to v5.29.2, c/common to v0.57.3 (fixes bsc#1219563)
* Mon Jan 22 2024 dcermak@suse.com
- Update to version 1.14.1:
  * Bump to v1.14.1
  * fix(deps): update module github.com/containers/common to v0.57.2
  * fix(deps): update module github.com/containers/image/v5 to v5.29.1
  * chore(deps): update dependency containers/automation_images to v20240102
  * Fix libsubid detection
  * fix(deps): update module golang.org/x/term to v0.16.0
  * fix(deps): update golang.org/x/exp digest to 02704c9
  * chore(deps): update dependency containers/automation_images to v20231208
  * [skip-ci] Update actions/stale action to v9
  * fix(deps): update module github.com/containers/common to v0.57.1
  * fix(deps): update golang.org/x/exp digest to 6522937
  * DOCS: add Gentoo in install.md
  * DOCS: Update to add Arch Linux in install.md
  * fix(deps): update module golang.org/x/term to v0.15.0
  * Bump to v1.14.1-dev
* Thu Nov 23 2023 danish.prakash@suse.com
- Update to version 1.14.0:
  * Bump to v1.14.0
  * fix(deps): update module github.com/containers/common to v0.57.0
  * chore(deps): update dependency containers/automation_images to v20231116
  * fix(deps): update module github.com/containers/image/v5 to v5.29.0
  * Add documentation and smoke tests for the new --compat-auth-file options
  * Update c/image and c/common to latest
  * fix(deps): update module github.com/containers/storage to v1.51.0
  * fix(deps): update module golang.org/x/term to v0.14.0
  * fix(deps): update module github.com/spf13/cobra to v1.8.0
  * [CI:DOCS] Update dependency golangci/golangci-lint to v1.55.2
  * [CI:DOCS] Update dependency golangci/golangci-lint to v1.55.1
  * fix(deps): update github.com/containers/common digest to 3e5caa0
  * chore(deps): update module google.golang.org/grpc to v1.57.1 [security]
  * fix(deps): update module github.com/containers/ocicrypt to v1.1.9
  * Update github.com/klauspost/compress to v1.17.2
  * chore(deps): update module github.com/docker/docker to v24.0.7+incompatible [security]
  * Fix ENTRYPOINT documentation, drop others.
  * Remove unused environment variables in Cirrus
  * [CI:DOCS] Update dependency golangci/golangci-lint to v1.55.0
  * chore(deps): update dependency containers/automation_images to v20231004
  * chore(deps): update module golang.org/x/net to v0.17.0 [security]
  * copy: Note support for `zstd:chunked`
  * fix(deps): update module golang.org/x/term to v0.13.0
  * fix(deps): update module github.com/docker/distribution to v2.8.3+incompatible
  * fix(deps): update github.com/containers/common digest to 745eaa4
  * Packit: switch to @containers/packit-build team for copr failure notification comments
  * Packit: tag @lsm5 on copr build failures
  * vendor of containers/common
  * fix(deps): update module github.com/opencontainers/image-spec to v1.1.0-rc5
  * fix(deps): update module github.com/containers/common to v0.56.0
  * Cirrus: Remove multi-arch skopeo image builds
  * fix(deps): update module github.com/containers/image/v5 to v5.28.0
  * Increase the golangci-lint timeout
  * fix(deps): update module github.com/containers/storage to v1.50.2
  * fix(deps): update module github.com/containers/storage to v1.50.1
  * fix(deps): update golang.org/x/exp digest to 9212866
  * Fix a man page link
  * fix(deps): update github.com/containers/image/v5 digest to 58d5eb6
  * GHA: Closed issue/PR comment-lock test
  * fix(deps): update module github.com/containers/common to v0.55.4
  * fix(deps): update module github.com/containers/storage to v1.49.0
  * rpm: spdx compatible license field
  * chore(deps): update dependency golangci/golangci-lint to v1.54.2
  * chore(deps): update dependency containers/automation_images to v20230816
  * Packit: set eln target correctly
  * packit: Build PRs into default packit COPRs
  * DOCS: Update Go version requirement info
  * DOCS: Add information about the cross-build
  * fix(deps): update module github.com/containers/ocicrypt to v1.1.8
  * fix(deps): update module github.com/containers/common to v0.55.3
  * Update c/image after https://github.com/containers/image/pull/2070
  * chore(deps): update dependency golangci/golangci-lint to v1.54.1
  * chore(deps): update dependency containers/automation_images to v20230809
  * fix(deps): update golang.org/x/exp digest to 352e893
  * chore(deps): update dependency containers/automation_images to v20230807
  * Update to Go 1.19
  * fix(deps): update module golang.org/x/term to v0.11.0
  * Update c/image for golang.org/x/exp
  * RPM: define gobuild macro for rhel/centos stream
  * Fix handling the unexpected return value combination from IsRunningImageAllowed
  * Close the PolicyContext, as required by the API
  * Use globalOptions.getPolicyContext instead of an image-targeted SystemContext
  * Packit: remove pre-sync action
  * fix(deps): update module github.com/containers/common to v0.55.2
  * proxy: Change the imgid to uint64
  * [CI:BUILD] Packit: install golist before updating downstream spec
  * Update module golang.org/x/term to v0.10.0
  * Bump to v1.14.0-dev
  * Bump to v1.13.0
* Tue Oct 10 2023 danish.prakash@suse.com
- Bump go version to 1.21 (bsc#1215611)
* Fri Aug 11 2023 danish.prakash@suse.com
- Update to version 1.13.2:
  * [release-1.13] Bump to v1.13.2
  * [release-1.31] Bump c/common v0.55.3
  * Packit: remove pre-sync action
  * [release-1.13] Bump to v1.13.2-dev
* Tue Jul 25 2023 danish.prakash@suse.com
- Update to version 1.13.1:
  * [release-1.13] Bump to v1.13.1
  * [release-1.13] Bump c/common to v0.55.2
  * [release-1.13 backport] [CI:BUILD] Packit: install golist before updating downstream spec
  * [release-1.13] Bump to v1.13.1-dev
* Mon Jul 10 2023 danish.prakash@suse.com
- Update to version 1.13.0:
  * Bump to v1.13.0
  * proxy: Policy verification of OCI Image before pulling
  * Update module github.com/opencontainers/image-spec to v1.1.0-rc4
  * Update module github.com/containers/common to v0.55.1
  * Update module github.com/containers/common to v0.54.0
  * Update module github.com/containers/image/v5 to v5.26.0
  * [CI:BUILD] RPM: fix ELN builds
  * Update module github.com/containers/storage to v1.47.0
  * Packit: easier to read distro conditionals
  * Update dependency golangci/golangci-lint to v1.53.3
  * Help Renovate manage the golangci-lint version
  * Minor: Cleanup renovate configuration
  * Update dependency containers/automation_images to v20230614
  * Update module golang.org/x/term to v0.9.0
  * [CI:BUILD] Packit: add jobs for downstream Fedora package builds
  * Update module github.com/sirupsen/logrus to v1.9.3
  * Update dependency containers/automation_images to v20230601
  * Update golang.org/x/exp digest to 2e198f4
  * Update github.com/containers/image/v5 digest to e14c1c5
  * Update module github.com/stretchr/testify to v1.8.4
  * Update module github.com/stretchr/testify to v1.8.3
  * Update dependency containers/automation_images to v20230517
  * Update module github.com/sirupsen/logrus to v1.9.2
  * Update module github.com/docker/distribution to v2.8.2+incompatible
  * Trigger an update of the ostree_ext container image
  * Update c/image with https://github.com/containers/image/pull/1944
  * Update module github.com/containers/common to v0.53.0
  * Update module golang.org/x/term to v0.8.0
  * Update dependency containers/automation_images to v20230426
  * Update golang.org/x/exp digest to 47ecfdc
  * Emphasize the semantics of --preserve-digests a tiny bit
  * Improve the static build documentation a tiny bit
  * Bump to v1.12.1-dev
* Thu Apr 20 2023 danish.prakash@suse.com
- Update to version 1.12.0:
  * Release 1.12.0
  * Update module github.com/containers/common to v0.52.0
  * Update module github.com/containers/storage to v1.46.1
  * Add (make tools) to install (for now only) golangci-lint, use it in Cirrus
  * Use golangci-lint instead of golint
  * Finally, eliminate hack/make.sh
  * Actually fail if (go vet) fails
  * Speed up validate-git-marks by about a factor of three
  * Don't use hack/make.sh for validate-git-marks
  * Test all files by validate-git-marks
  * Simplify the package list of (go vet)
  * Don't use hack/make.sh for validate-gofmt
  * Run gofmt on all files, not just the changed ones
  * Don't use hack/make.sh for validate-lint
  * Lint many more files in validate-lint
  * Don't use hack/make.sh for validate-vet
  * Remove no-longer-necessary module options
  * Fix Makefile dependencies
  * Remove some outright unused code from hack/make*
  * Cross-link the top-level and subcommand option lists
  * Fix error handling of signature.NewEphemeralGPGSigningMechanism
  * chore(deps): update dependency containers/automation_images to v20230405
  * Avoid use of a deprecated capability.NewPid
  * fix(deps): update module github.com/spf13/cobra to v1.7.0
  * fix(deps): update module github.com/containers/image/v5 to v5.25.0
  * fix(deps): update module golang.org/x/term to v0.7.0
  * Use multiple fingerprint function Allow comma separated fingerprint list
  * Review comments (to be squashed later
  * Rename argument. Only use any with public key file. Double check fingerprint is in public key file.
  * Verify signatures from a trust store
  * Update c/image from the main branch
  * Update module github.com/containers/common to v0.51.2
  * Update dependency containers/automation_images to v20230330
  * systemtests: Fix 040-local-registry-auth about XDG_RUNTIME_DIR
  * [CI:BUILD] Packit: trigger builds on commit to main branch
  * [skip-ci] Update actions/stale action to v8
  * Make the installation instructions more prominent in README.md
  * Update dependency containers/automation_images to v20230320
  * Update module github.com/containers/common to v0.51.1
  * Cirrus: Update CI VM images
  * bump golang.org/x/net to v0.8.0
  * Update module golang.org/x/term to v0.6.0
  * Simplify inspectOptions.writeOutput a bit more
  * Factor out the output of data in (skopeo inspect)
  * Use io.WriteString
  * Update module github.com/stretchr/testify to v1.8.2
  * Update module github.com/containers/storage to v1.45.4
  * Update golang.org/x/exp digest to 5e25df0
  * Fix formatting of inspect examples
  * Use common library reporter
  * Fix some warnings
  * Fix tabelating output in (skopeo inspect --format)
  * Corrected typo in skopeo-sync and updated description
  * Replace gopkg.in/check.v1 by github.com/stretchr/testify/suite/
  * Update c/image after https://github.com/containers/image/pull/1842
  * [CI:BUILD] Packit: initial enablement
  * Renovate: c/common rule moved to defaults
  * Update c/image after https://github.com/containers/image/pull/1816
  * Run codespell on codebase
  * [CI:DOCS] Disable dependabot
  * Update module golang.org/x/term to v0.5.0
  * Update golang.org/x/exp digest to 46f607a
  * Remove unnecessary blank lines
  * Pre-allocate an array
  * Simplify a condition
  * Rename a variable to avoid an underscore
  * Add missing comment punctuation
  * Fix, or remove, comments using lint syntax
  * Simplify an increment
  * Reformat import statements
  * Use %%w when wrapping errors
  * Remove a duplicate word
  * Use net/netip.Addr instead of net.IP
  * s/interface{}/any/g
  * Use golang.org/x/exp
  * Use strings.Cut
  * go mod tidy -go=1.18
  * [CI:BUILD] enable debuginfo for el8 copr builds
  * [CI:BUILD] copr: fix el8 build and enable debuginfo
  * Cirrus: Use human-readable CI VM Images
  * Update module gopkg.in/yaml.v2 to v3
  * Add unit tests for tlsVerifyConfig's yaml.Unmarshaler
  * [CI:DOCS] Fix up language in README
* Tue Apr  4 2023 danish.prakash@suse.com
- Update to version 1.11.2:
  * Release 1.11.2
  * bump golang.org/x/net to v0.7.0
  * [release-1.11] Bump to v1.11.2-dev
* Fri Feb 17 2023 danish.prakash@suse.com
- Update to version 1.11.1:
  * [release-1.11] Bump to v1.11.1
  * Update to c/image 5.24.1
  * Move to v1.11.1-dev
  * Bump to v1.11.0
  * [CI:DOCS] Format manual page documents
  * Update module github.com/containers/common to v0.51.0
  * Update module github.com/containers/image/v5 to v5.24.0
  * Add (skopeo generate-sigstore-key)
  * Update c/image after https://github.com/containers/image/pull/1810
  * Touch up conscious language issues
  * Partially fix removal of temporary data in (make test-system)
  * Don't affect $XDG_RUNTIME_DIR of Podman starting the registry
  * Update module github.com/containers/storage to v1.45.3
  * Fix storage.conf setup in test-system
  * Fix (test-integration), in a container without CI
  * Cirrus: Fix c/image CI testing
  * Bump github.com/containers/ocicrypt from 1.1.6 to 1.1.7
  * Cirrus: Add a common intra-test reset function
  * Fix unnecessary use of podman in CI test
  * Cirrus: Update to F37 CI VM Images
  * Cirrus: Remove redundant package install attempt
  * fix(deps): update module github.com/containers/storage to v1.45.1
  * Add support for Fulcio and Rekor, and --sign-by-sigstore=param-file
  * Update c/image after https://github.com/containers/image/pull/1787
  * fix(deps): update module github.com/containers/storage to v1.45.0
  * Cirrus: Skip OSX CI on release-branches
  * Correctly use the stdout parameter in some places
  * fix(deps): update module golang.org/x/term to v0.4.0
  * [skip-ci] Update actions/stale action to v7
  * proxy: Fix leak of blobs from containers-storage
  * vendor: Bump golang.org/x/net to 4.0
  * proxy: Ensure images are closed when proxy is shutting down
  * Add an example for creating a docker-archive file
  * proxy: Add GetLayerInfo API
  * fix(deps): update module golang.org/x/term to v0.3.0
  * [skip-ci] GHA/Cirrus-cron: Fix execution order
  * Update skopeo-inspect man page example
  * README: Update example to show newly exposed LayerData
  * [CI:BUILD] Cirrus: Migrate OSX task to M1
  * Adds sync with tag suffix example
  * GHA: Add cirrus-cron auto-rerun job
  * Adds `--append-suffix` flag to sync
  * fix(deps): update module github.com/containers/storage to v1.44.0
  * Cirrus: Add reverse-deps. test to verify proxy ext
  * [skip-ci] Update actions/stale action to v6
  * fix(deps): update module golang.org/x/term to v0.2.0
  * Renovate: Override global no-rebase option
  * chore(deps): update actions/stale to v3
  * fix(deps): update module github.com/spf13/cobra to v1.6.1
  * Close a HTTP response body
  * fix(deps): update module golang.org/x/term to v0.1.0
  * fix(deps): update module github.com/stretchr/testify to v1.8.1
  * Update to c/image main branch
  * bump to v1.11.0-dev
  * chore(deps): add renovate.json
  * proxy: Bump semver for OpenImageOptional
  * proxy: Add `OpenImageOptional`
  * Add a workaround for public.ecr.aws not implementing tag list at all
  * Update AWS workaround to use Golang types
  * Reorganize the "list tags failed" logic in inspect.go a bit
  * Remove a (skopeo inspect) workaround for IBM Bluemix
  * Fix an error message to refer to repo, not a single image
  * Remove a special case for failing to list tags in (skopeo sync)
  * Update tests for changed error texts
  * Include c/image after https://github.com/containers/image/pull/1299
  * Fold a long line.
  * Remove single-use "wanted" variables
  * Bump github.com/spf13/cobra from 1.5.0 to 1.6.0
  * Bump github.com/containers/ocicrypt from 1.1.5 to 1.1.6
  * Bump github.com/opencontainers/image-spec from 1.1.0-rc1 to 1.1.0-rc2
  * Bump to v1.10.1-dev
* Wed Jan 25 2023 dcermak@suse.com
- stop building with libostree, this has been disabled upstream three years ago
  and is now broken
- add fish & zsh completion subpackages
- correct -completion subpackages requires, buildarch & supplements
- remove outdated buildtags for opensuse pre-Leap
- fix rpmlint filters
- Update to version 1.10.0:
  * Release v1.10.0
  * Update for https://github.com/klauspost/pgzip/pull/50
  * Revert addition of -compat=1.17 to (go mod tidy)
  * Update vendor containers/(common,image)
  * [CI:DOCS] Add quay-description update reminder
  * Bump github.com/containers/storage from 1.42.0 to 1.43.0
  * Fix documentation in the default registries.d content.
  * default.yaml should have all options commented
  * warn about ineffective destination opts in sync cmd
  * document imageDestOptions.warnAboutIneffectiveOptions()
  * warn users about --dest-compress and --dest-decompress misuse
  * warn users about --dest-compress and --dest-decompress misuse
  * Don't abort sync if the registry returns invalid tags
  * add inspect layersData
  * Stop using docker/docker/pkg/homedir in tests
  * Update for c/image's update of github.com/gobuffalo/pop
  * Don't include git commit from a parent directory in the --version output
  * Remove unused GIT_BRANCH definition
  * Point at --all in the --preserve-digests option documentation
  * Talk about "registry repositories" in (skopeo sync) documentation
  * Fix looking for commands with GNU make 4.2.1
  * Fix a comment
  * Reformat with Go 1.19's gofmt
  * Fix running tests on macOS
  * Optimize upstream skopeo container image build
  * GHA: Re-use identical workflow from buildah repo
  * Bump to v1.9.3-dev
  * Release v1.9.2
  * Bump github.com/containers/common from 0.49.0 to 0.49.1
  * Cirrus: Update CI VM images to match podman CI
  * [CI:DOCS] Cirrus: Use the latest imgts container
  * Bump to v1.9.2-dev
  * Release v1.9.1
  * Stop using deprecated names from c/common/pkg/retry
  * Update to github.com/containers/common v0.49.0
  * Update to github.com/containers/image/v5 v5.22.0
  * Bump github.com/containers/storage from 1.41.0 to 1.42.0
  * Bump github.com/sirupsen/logrus from 1.8.1 to 1.9.0
  * Bump to v1.9.1-dev
  * Release v1.9.0
  * Update for the renames of sigstore to lookaside
  * Add --sign-by-sigstore-private-key to (skopeo copy) and (skopeo sync)
  * Vendor in c/image with sigstore support
  * Revert "Change a repo used for sync tests"
  * Vendor unreleased c/image with OCI artifact support
  * Use errors.As() instead of direct type checks
  * Remove uses of pkg/errors
  * Modify error messages on failures to close
  * Introduce noteCloseFailure, use it for reporting of cleanup errors
  * Bump github.com/stretchr/testify from 1.7.5 to 1.8.0
  * Update IRC information
  * Use bytes.ReplaceAll instead of bytes.Replace(..., -1)
  * Update & fix skopeo multiarch image Containerfiles
  * Cirrus: Migrate multiarch build off github actions
  * Bump github.com/stretchr/testify from 1.7.4 to 1.7.5
  * Bump github.com/stretchr/testify from 1.7.2 to 1.7.4
  * Bump github.com/spf13/cobra from 1.4.0 to 1.5.0
  * [CI:DOCS] skopeo.spec.rpkg: Fix syntax highlighting
  * [CI:DOCS] Makefile: include cautionary note for rpm target
  * CoPR: Autobuild rpm on rhcontainerbot/podman-next
  * Enable schema1 support on the test registries
  * Update for docker/distribution CLI change
  * Use an updated CI image
  * Change a repo used for sync tests
  * Use testing.T.Setenv instead of os.Setenv in tests
  * Update go.mod to Go 1.17
  * Bump github.com/docker/docker
  * Bump github.com/stretchr/testify from 1.7.1 to 1.7.2
  * Bump github.com/containers/ocicrypt from 1.1.4 to 1.1.5
  * Cirrus: use Ubuntu 22.04 LTS
  * Update to github.com/opencontainers/runc >= 1.1.2
  * fix make completions for all POSIX shells
  * Update to gopkg.in/yaml.v3 v3.0.0
  * Updated skopeo logo with new artwork
  * [CI:DOCS] Pin actions to a full length commit SHA
  * shell completion: add completion for transports names
  * shell completion: add install instructions docs
  * shell completion: add Makefile target
  * Stop calling gpgme-config
  * Update c/image
  * Remove cgo_pthread_ordering_workaround.go
  * add completion command to generate shell completion scripts
  * Bump github.com/docker/docker
  * Bump github.com/containers/storage from 1.40.2 to 1.41.0
  * Avoid hard-coding the location of bash
  * Config files live in /usr/local/etc on FreeBSD
  * Bump github.com/docker/docker
  * Move to v1.8.1-dev
  * Bump to v1.8.0
  * Bump ocicrypt to v1.1.4
  * Vendor in containers/storage v1.40.2
  * Vendor in containers/(common, storage, image)
  * [CI:DOCS] install.md: include distro package info links
  * [CI:DOCS] install.md: remove Kubic package info for Ubuntu
  * Cirrus: Update to F36 w/ netavark+aardvark-dns
  * Update vendor of containers/(common,storage,image)
  * Use filepath.WalkDir instead of filepath.Walk
  * Extract four copies of the same loop into a function
  * Update users of deprecated io/ioutil
  * Add option to specify the identity for signing
  * Bump containers/image to include sign identity option
  * delete non-existent option in the cmdline example
  * Add dry-run mode to skopeo-sync
  * Update skopeoimage/README.md that tags are v-prefixed
  * Bump to v1.7.1-dev
  * Release 1.7.0
  * Bump github.com/prometheus/client_golang to v1.11.1
  * Bump github.com/containers/common from 0.47.4 to 0.47.5
  * Bump github.com/containers/storage from 1.38.2 to 1.39.0
  * Bump github.com/docker/docker
  * Improve the (skopeo delete) man page
  * Bump github.com/containers/ocicrypt from 1.1.2 to 1.1.3
  * Update the command to install golint
  * Formally record that we require Go 1.15
  * Use check.C.MkDir() instead of manual ioutil.TempDir() calls
  * Update to Go 1.14 and revendor
  * Use assert.ErrorContains
  * Bump github.com/stretchr/testify from 1.7.0 to 1.7.1
  * Simplify the proxy server a bit
  * Add various missing error handling
  * Remove assignments to an unused variable
  * Rename "self" receiver
  * Add support for docker-archive: to skopeo list-tags
  * Bump github.com/spf13/cobra from 1.3.0 to 1.4.0
  * Bump github.com/docker/docker
  * Update github.com/containerd/containerd
  * Bump github.com/containers/image/v5 from 5.19.1 to 5.20.0
  * do not recommend upgrading all packages
  * Improve a comment in the 010-inspect.bats test
  * Move to v1.7.0-dev
  * Bump to v1.6.1
  * Work around systemd-resolved's handling of .invalid domains
  * Beautify a few calls
  * Only look for the layer digests in the Layers field.
  * Don't expect the config blob to be listed in (skopeo inspect)
  * Cirrus: Use updated VM images
  * Bump c/common to v0.47.4
  * tests: skip sif test on RHEL
  * Bump to v1.6.1-dev
  * Release v1.6.0
  * Bump version of containers/image and containers/common
  * Improve the documentation of boolean flags
  * Document where various fields of (skopeo inspect) come from
  * Improve the documentation of the argument to (skopeo inspect)
  * Update vendor of containers/storage and containers/common
  * add a SIF systemtest
  * Update vendor of containers/common
  * Github workflow: Fix yaml syntax
  * Bump github.com/containers/storage from 1.38.0 to 1.38.1
  * prompt-less signing via passphrase file
  * Github-workflow: Report both failures and errors
  * Run codespell on code
  * Update the vendor of containers/common
  * Bump github.com/containers/storage from 1.37.0 to 1.38.0
  * Update github.com/containerd/containerd to 1.5.9
  * Fix the pseudo-version of github.com/opencontainers/image-spec
  * Update github.com/opencontainers/runc to v1.0.3
  * Bump github.com/spf13/cobra from 1.2.1 to 1.3.0
  * Bump github.com/docker/docker
  * Add option to preserve digests on copy
  * Add option to preserve digests on copy
  * proxy: Also bump compatible semver
  * proxy: Add a GetFullConfig method
  * Update github.com/containerd/containerd to v1.5.8
  * Update opencontainers/image-spec
  * Add an option to allow copying image indexes alone
  * Use a dynamic temp dir for test
  * Bump to 1.5.3-dev
  * Release 1.5.2
  * Update to c/image v5.17.0
  * Cirrus: Bump Fedora to release 35 & Ubuntu to 21.10
  * Bump github.com/docker/docker
  * proxy: Uncapitalize all errors
  * tests: Add new "procutils" that exposes PDEATHSIG
  * proxy_test: Test `GetConfig`
  * proxy_test: Add helper to read all from a reply
  * proxy_test: Add a helper method to call without fd
  * proxy: Add support for manifest lists
  * tests/integration/proxy_test: New test that exercises `proxy.go`
  * proxy: Use float → int helper for pipeid
  * proxy: Add a helper to return a byte array
  * proxy: Add an API to fetch the config upconverted to OCI
  * Fix bug that prevented useful diagnostics on registry fail
  * use fedora:latest in contrib/skopeoimage/*/Dockerfile
  * Move to v1.5.2-dev
  * Bump to v1.5.1
  * main: Error out if an unrecognized subcommand is provided
  * move optional-flag code to c/common/pkg/flag
  * Add --dest-precompute-digests option for docker
  * bump containers/image to 2541165
  * Add instructions to generate static binaries
  * Add new `experimental-image-proxy` hidden command
  * issue#785 inspect command - introduce a way to skip querying available tags for an image
  * Document container images as an alternative to installing packages
  * Introduce --username and --password to pass credentials
  * Move to v1.5.1-dev
* Fri Oct  8 2021 info@paolostivanin.com
- Update to version 1.5.0:
  * bump deps
  * Update VM Images + Drop prior-ubuntu references
  * Update installation doc with latest steps
  * Introduce a --ignore option to allow "sync" command to continue
    syncing even after a particular image sync fails
  * vendor-in-container: update to golang:1.16
  * update c/common, c/image, c/storage
  * Add timeouts when waiting on OpenShift or the registry to start
  * Add docs and bash completions
  * Add support for decompressing while copying to dir://
  * Update to enabled containers/image version
  * Fix two instances of unused err found by go-staticcheck
  * Test both imageOptions and imageDestOptions in TestTLSVerifyFlags
  * Split testing of --tls-verify into separate TestTLSVerifyFlags
  * Add the --tls-verify option to (skopeo logout)
  * Added `format` parameter to `sync` command
  * copy: Add --digestfile
* Wed May 19 2021 rpm@fthiessen.de
- Update to version 1.2.3:
  * Fix for login / logout registry argument
  * Upgrade dsnet/compress to avoid vulnerable xz version
  * Enable 'OptimizeDestinationImageAlreadyExists' feature
  * 020-copy.bats: check that we set the manifest type correctly
  * Set User-Agent to skopeo/$VERSION
  * Rebase against master and improve comment about gpgme-config
  * Fix Makefile to handle PREFIX correctly
- Add bash-completion package
* Fri Jan 22 2021 dmueller@suse.com
- Update to version 1.2.1:
  * Bump to v1.2.1
  * Update nix pin with `make nixpkgs`
  * Add a smoke test for signedIdentity:remapIdentity
  * Split copyWithSignedIdentity from TestCopyVerifyingMirroredSignatures
  * integration test: sync k8s.gcr.io/pause instead of docker.io/alpine
  * integration test: use fedora-minimal for most manifest list tests
  * Update vendor of containers/common and containers/storage
  * Fix reading the after-sync list of tags in SyncSuite.TestYamlUntagged
  * Bump github.com/containers/common from 0.31.1 to 0.31.2
* Wed Jul 29 2020 sgrunert@suse.com
- Update to skopeo v1.1.1:
  * Run htpasswd from our build-container instead of registry:2
  * Vendor golang.org/x/text@v0.3.3
* Wed Jun 24 2020 rhafer@suse.com
- Update to skopeo v1.1.0:
  * Add Skopeo Stable Image Dockerfile for Quay
  * Add tags to support regular expressions in yaml conf
  * Add tags to support regular expressions without breaking the
    old ones in yaml conf
  * Add upstream and testing container images
  * Add upstream and testing container images
  * Bump github.com/containers/storage from 1.20.1 to 1.20.2
  * Bump github.com/stretchr/testify from 1.6.0 to 1.6.1
  * Clarify control flow when handling the tags list
  * Clarify imagesToCopy control flow
  * Correct a typo in docs/skopeo-sync.1.md
  * Don't use path.Join to form repository names
  * Drop redundant fmt.Sprintf inside erorrs.Wrapf/Errorf
  * Fix error handling on invalid regex
  * Fix the recently added example in the man page.
  * Inline isTagSpecified into its only caller
  * Only create a SystemContext once per registry
  * Remove the repoReference parameter of imagesToCopyFromRepo
  * Share the logrus.WithFields settings over the loop bodies
  * Use MatchString instead of Match with a manual conversion
  * Use a reference.Named, not types.ImageReference, in
    imagesToCopyFromRepo
  * Use a separate field for the "sync images with tag
    matching regex" feature
  * Use reference.Tagged to extract the tag from a reference
  * Work with a reference.Named, not strings, in
    imagesToCopyFromRegistry
* Thu May 21 2020 info@paolostivanin.com
- Update to skopeo v1.0.0:
  * Add skopeo Login from c/common
  * Add skopeo login&logout
  * Add Security Policy
  * Add tests for using signatures with mirrors
  * Update c/image for containers/image#912
  * Use cobra in skopeo
  * Update containers/image to v5.4.4
  * Bump github.com/containers/storage from 1.18.2 to 1.19.0
  * v0.11.2 containers/common
* Tue Apr 14 2020 sgrunert@suse.com
- Update to skopeo v0.2.0:
  - Update on #834: force runc only when cgroupsv1
  - Update docs/skopeo.1.md
  - Add example with repository
  - Skopeo should support for BigFilesTemporaryDir (SystemContext)
  - Use fully-qualified image names
  - Add support for REGISTRY_AUTH_FILE
  - Partial image encryption support
  - Remove the list_tags integration test since it does not cover
    much not already tested by the upstream container/images repo
    or local unit tests
  - Updates based on code review to simplify logic and tests
  - Fix inconsistency in manpage example for list-tags
  - Adds "list-tags" command to list tags with no known tag
    required
* Wed Mar  4 2020 rhafer@suse.com
- Removed patches that were merged upstream:
  - 0002-Add-set-of-image-options-used-only-for-docker-transp.patch
  - bsc1115165-0001-Introduce-the-sync-command.patch
  - CVE-2019-10214.patch
- Update to skopeo v0.1.41 (bsc#1165715):
  - Bump github.com/containers/image/v5 from 5.2.0 to 5.2.1
  - Bump gopkg.in/yaml.v2 from 2.2.7 to 2.2.8
  - Bump github.com/containers/common from 0.0.7 to 0.1.4
  - Remove the reference to openshift/api
  - vendor github.com/containers/image/v5@v5.2.0
  - Manually update buildah to v1.13.1
  - add specific authfile options to copy (and sync) command.
  - Bump github.com/containers/buildah from 1.11.6 to 1.12.0
  - Add context to --encryption-key / --decryption-key processing
    failures
  - Bump github.com/containers/storage from 1.15.2 to 1.15.3
  - Bump github.com/containers/buildah from 1.11.5 to 1.11.6
  - remove direct reference on c/image/storage
  - Makefile: set GOBIN
  - Bump gopkg.in/yaml.v2 from 2.2.2 to 2.2.7
  - Bump github.com/containers/storage from 1.15.1 to 1.15.2
  - Introduce the sync command
  - openshift cluster: remove .docker directory on teardown
  - Bump github.com/containers/storage from 1.14.0 to 1.15.1
  - document installation via apk on alpine
  - Fix typos in doc for image encryption
  - Image encryption/decryption support in skopeo
  - make vendor-in-container
  - Bump github.com/containers/buildah from 1.11.4 to 1.11.5
  - Travis: use go v1.13
  - Use a Windows Nano Server image instead of Server Core for
    multi-arch testing
  - Increase test timeout to 15 minutes
  - Run the test-system container without --net=host
  - Mount /run/systemd/journal/socket into test-system containers
  - Don't unnecessarily filter out vendor from (go list ./...)
    output
  - Use -mod=vendor in (go {list,test,vet})
  - Bump github.com/containers/buildah from 1.8.4 to 1.11.4
  - Bump github.com/urfave/cli from 1.20.0 to 1.22.1
  - skopeo: drop support for ostree
  - Don't critically fail on a 403 when listing tags
  - Revert "Temporarily work around auth.json location confusion"
  - Remove references to atomic
  - Remove references to storage.conf
  - Dockerfile: use golang-github-cpuguy83-go-md2man
  - bump version to v0.1.41-dev
  - systemtest: inspect container image different from current
    platform arch
- Changes in v0.1.40:
  - vendor containers/image v5.0.0
  - copy: add a --all/-a flag
  - System tests: various fixes
  - Temporarily work around auth.json location confusion
  - systemtest: copy: docker->storage->oci-archive
  - systemtest/010-inspect.bats: require only PATH
  - systemtest: add simple env test in inspect.bats
  - bash completion: add comments to keep scattered options in sync
  - bash completion: use read -r instead of disabling SC2207
  - bash completion: support --opt arg completion
  - bash-completion: use replacement instead of sed
  - bash completion: disable shellcheck SC2207
  - bash completion: double-quote to avoid re-splitting
  - bash completions: use bash replacement instead of sed
  - bash completion: remove unused variable
  - bash-completions: split decl and assignment to avoid masking
    retvals
  - bash completion: double-quote fixes
  - bash completion: hard-set PROG=skopeo
  - bash completion: remove unused variable
  - bash completion: use `||` instead of `-o`
  - bash completion: rm eval on assigned variable
  - copy: add --dest-compress-format and --dest-compress-level
  - flag: add optionalIntValue
  - Makefile: use go proxy
  - inspect --raw: skip the NewImage() step
  - update OCI image-spec to
    775207bd45b6cb8153ce218cc59351799217451f
  - inspect.go: inspect env variables
  - ostree: use both image and & storage buildtags
* Mon Sep  2 2019 sgrunert@suse.com
- Add patch for CVE-2019-10214. bsc#1144065
  + CVE-2019-10214.patch
* Wed Aug  7 2019 mvedovati@suse.com
- Update to skopeo v0.1.39 (bsc#1159530):
  - inspect: add a --config flag
  - Add --no-creds flag to skopeo inspect
  - Add --quiet option to skopeo copy
  - New progress bars
  - Parallel Pulls and Pushes for major speed improvements
  - containers/image moved to a new progress-bar library to fix various
    issues related to overlapping bars and redundant entries.
  - enforce blocking of registries
  - Allow storage-multiple-manifests
  - When copying images and the output is not a tty (e.g., when piping to a
    file) print single lines instead of using progress bars. This avoids
    long and hard to parse output
  - man pages: add --dest-oci-accept-uncompressed-layers
  - completions:
  - Introduce transports completions
  - Fix bash completions when a option requires a argument
  - Use only spaces in indent
  - Fix completions with a global option
  - add --dest-oci-accept-uncompressed-layers
- Update bsc1115165-0001-Introduce-the-sync-command.patch and add
  0002-Add-set-of-image-options-used-only-for-docker-transp.patch
  required by the updated sync patch.
* Tue Nov 27 2018 mvedovati@suse.com
- Disable ostree repository types for SLE, as this feature requires libostree
  that is not yet available in the Server Application module where skopeo is
  located.
* Thu Nov 15 2018 mvedovati@suse.com
- Update to skopeo v0.1.32:
  * Add command time out support
  * Updates to vendored libraries
- Add a patch that implements the `skopeo sync` command, generated from the
  upstream PR: https://github.com/containers/skopeo/pull/524
  Fix bsc#1115165
  + bsc1115165-0001-Introduce-the-sync-command.patch
- Update project location from 'projectatomic' to 'containers'
* Mon Jul 30 2018 vrothberg@suse.com
- Update to skopeo v0.1.31:
  * Fix compilation on i586
* Wed Jun 13 2018 dcassany@suse.com
- Make use of %%license macro
* Tue May 22 2018 vrothberg@suse.com
- Update to skopeo v0.1.30:
  * skopeo-copy: docker-archive: multitag support
  * Updates to vendored libraries
* Tue Mar 27 2018 vrothberg@suse.com
- Run spec-cleaner on skopeo.spec
- Enable ostree support on Tumbleweed, Leap 15 and SLE 15
- Enable support for containers/storage, which is especially useful to further
  support Podman and cri-o.
- Update to skopeo v0.1.28:
  * vendor: bump containers/image and containers/image
  * Cleanup skopeo man page and README.md
  * Use credentials from authfile for skopeo commands
  * Update to a newer containers/storage master
  * Add global --override-arch and --override-os options
* Mon Feb 12 2018 vrothberg@suse.com
- Add requirement on libcontainers-common, which now provides the
  /etc/containers/policy.json config.
* Thu Feb  1 2018 ro@suse.de
- do not build on s390, only on s390x (no go on s390)
* Mon Nov 20 2017 asarai@suse.com
- Update to skopeo v0.1.26. This includes a fix for CVE-2017-14992.
- Disable containers/storage integration by default (through
  containers_image_storage_stub), as it is very dodgy and not widely used.
* Sat Oct 21 2017 asarai@suse.com
- Update to skopeo v0.1.24. Upstream changelog:
  * Improvements to macOS builds: A make binary-local should work without extra options.
  * make install on macOS now installs to /usr/local
  * The destination in docker-archive: now can be a pipe.
  * When building with containers_image_openpgp, signatures with PGP v3 signature packets are accepted.
  * Unreadable /etc/docker/certs.d now only logs a warning instead of aborting the operation.
  * oci-layout: naming semantics changes:
  * A full range of org.opencontainers.image.ref.name values is now accepted
  * A name must be specified for oci-layout: destinations (it does not default to latest any more).
  * For oci-layout: sources, a name is now optional if the image index contains exactly one image (instead of using the image with the latest name).
  * Policy configuration identities of oci-layout: images now consist only of the directory name, to avoid the ambiguity created by the unspecified annotation values above.
  * ~/.docker/config.json credential helpers (configured in credHelpers) are now supported.
  * Annotations are now preserved when copying and compressing OCI images.
  * New transport oci-archive:, works exactly like oci-layout:, but works on tarballs instead of extracted directories.
  * When copying images, skopeo always asks for the same image schema, and optionally converts the image itself to make it acceptable to the destination, instead of asking for a schema dependent on the destinations’ capabilities (relying on the source to convert the image).
  * Improved installation instructions.
  * ostree: image names can now contain colons (e.g. port specifications)
  * skopeo now does not declare support for manifest lists, so that the source registry provides a single image. This allows skopeo copy to copy various images recently published to Docker Hub. (More complete support for manifest lists will come in the future.)
  * The containers-storage: backend has been updated, incl. support for the override_kernel_checks option.
  * Improved the output of progress bars in skopeo copy.
  * Fixed fetching blobs with external URLs in images served by docker/distribution registries.
  * OCI images now support reading blobs with external URLs, ands storing information about such blobs without copying the contents.
  * Writing ostree: images creates a docker.digest annotation.
  * docker/distribution registry credentials are now read from $XDG_RUNTIME_DIR/containers/auth.json before trying ~/.docker/config.json and ~/.dockercfg.
  * skopeo inspect no longer crashes on images where the config blob does not contain a container configuration.
* Wed Sep  6 2017 asarai@suse.com
- Add -buildmode=pie to fix bugs building on ppc64le.
* Sat Jul 22 2017 asarai@suse.com
- Update to skopeo v0.1.23. This supports OCI v1, as well as a variety of new
  transports such as docker-archive and ostree.
- Disable ostree builds by default with %%bcond_with, as only Tumbleweed has
  libostree and we need skopeo for KIWI.
* Fri Apr 14 2017 asarai@suse.com
- Update to skopeo 0.1.19, which supports 1.0.0-rc4 of the image-spec as well
  as all of our patches have been merged upstream.
  - 0001-docker-split-tarfile-code-from-docker-daemon-code.patch
  - 0002-docker-add-docker-archive-transport.patch
  - 0003-squashme-docker-tarfile-make-tagging-work-properly.patch
  - 0004-squashme-docker-archive-handle-mtrmac-s-comments.patch
  - 0005-squashme-docker-archive-correctly-handle-tagging.patch
  - 0006-copy-move-compression-to-separate-pkg.patch
  - 0007-docker-daemon-decompress-blobs-transparently-in-GetB.patch
  - oci-remove-MIME-type-autodetection.patch
* Wed Feb 15 2017 asarai@suse.com
- Add further patches to handle OCI <-> Docker translation properly. This is
  necessary for KIWI integration. https://github.com/containers/image/pull/237
  + oci-remove-MIME-type-autodetection.patch
* Tue Feb  7 2017 asarai@suse.com
- Add buildtags to handle the Docker-like buildtags such as
  libdm_no_deferred_remove and exclude_graphdriver_aufs.
* Tue Feb  7 2017 asarai@suse.com
- Add patches for docker-archive transport.
  + 0001-docker-split-tarfile-code-from-docker-daemon-code.patch
  + 0002-docker-add-docker-archive-transport.patch
  + 0003-squashme-docker-tarfile-make-tagging-work-properly.patch
  + 0004-squashme-docker-archive-handle-mtrmac-s-comments.patch
  + 0005-squashme-docker-archive-correctly-handle-tagging.patch
  + 0006-copy-move-compression-to-separate-pkg.patch
  + 0007-docker-daemon-decompress-blobs-transparently-in-GetB.patch
* Tue Feb  7 2017 asarai@suse.com
- Bump to skopeo v0.1.18. Many updates to containers/image, and fixes to the
  Docker v2s2 schema conversion.
* Tue Dec 13 2016 asarai@suse.com
- Bump to skopeo v0.1.17. This version includes many, many fixes to OCI image
  handling as well as adding features such as the docker-daemon: transport.
  There are also several UX fixes to how passwords are managed.
* Thu Dec  8 2016 asarai@suse.com
- Bump to v0.1.16+r54 (a865c07818ed914e2602205be6e9d67debc1d660). This is
  necessary so that we don't need to do major backporting of containers/image.
  skopeo intends to bump themselves to v0.1.17 in the coming week so this is
  just a temporary measure.
- Removed patches no longer needed.
  - oci-fix-mediatypes.patch
* Fri Nov 11 2016 asarai@suse.com
- Backport OCI mediatype fixes. https://github.com/projectatomic/skopeo/pull/221
  + oci-fix-mediatypes.patch
* Fri Nov 11 2016 asarai@suse.com
- Initial import of skopeo v0.1.16.
